@@ -1,7 +1,5 @@
-##' @title Statistical tests
-##'
 ##' Performs Likelihood-ratio, Wald and score tests
-##'
+##' @title Statistical tests
 ##' @aliases compare
 ##' @export
 ##' @param object \code{lvmfit}-object
@@ -42,7 +40,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
       contrast <- rep(0,length(coef(object)))
       myidx <- parpos(Model(object),p=par)
       contrast[myidx] <- 1
-      contrast <- diag(contrast)[contrast!=0,]
+      contrast <- diag(contrast,nrow=length(contrast))[which(contrast!=0),,drop=FALSE]
       if (!missing(null) && length(null)>1) null <- null[attributes(myidx)$ord]
   }
   ### Wald test
@@ -75,7 +73,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
     Q <- t(Bp-null)%*%Inverse(V)%*%(Bp-null)
     df <- qr(B)$rank; names(df) <- "df"
     attributes(Q) <- NULL; names(Q) <- "chisq";
-    pQ <- ifelse(df==0,NA,1-pchisq(Q,df))
+    pQ <- ifelse(df==0,NA,pchisq(Q,df,lower.tail=FALSE))
 
     method = "- Wald test -";
     cnames <- c()
@@ -106,7 +104,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
   ### Score test
   if (!missing(scoretest)) {
     altmodel <- Model(object)
-    if (class(scoretest)[1]=="formula") scoretest <- list(scoretest)
+    if (inherits(scoretest,"formula")) scoretest <- list(scoretest)
     for (i in scoretest) {
       regression(altmodel) <- i
     }
@@ -126,7 +124,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
                  )
     attributes(Q) <- NULL; names(Q) <- "chisq"
     df <- length(p0)-length(coef(object)); names(df) <- "df"
-    pQ <- ifelse(df==0,NA,1-pchisq(Q,df))
+    pQ <- ifelse(df==0,NA,pchisq(Q,df,lower.tail=FALSE))
     res <- list(data.name=as.character(scoretest),
                 statistic = Q, parameter = df,
                 p.value=pQ, method = "- Score test -")
@@ -137,7 +135,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
   ### Likelihood ratio test
   objects <- list(object,...)
   if (length(objects)<2) {
-    if (!("lvmfit"%in%class(object))) {
+    if (!(inherits(object,"lvmfit"))) {
       cc <- rbind(logLik(object),AIC(object))
       rownames(cc) <- c("logLik","AIC")
       colnames(cc) <-  ""
@@ -148,7 +146,7 @@ compare.default <- function(object,...,par,contrast,null,scoretest,Sigma,level=.
     df <- attributes(L1)$df-attributes(L0)$df; names(df) <- "df"
     Q <- abs(2*(L0-L1));
     attributes(Q) <- NULL; names(Q) <- "chisq";
-    pQ <- ifelse(df==0,NA,1-pchisq(Q,df))
+    pQ <- ifelse(df==0,NA,pchisq(Q,df,lower.tail=FALSE))
 
     values <- c(L0,L1); names(values) <- c("log likelihood (model)", "log likelihood (saturated model)")
     res <- list(statistic = Q, parameter = df,
@@ -178,7 +176,7 @@ comparepair <- function(x1,x2) {
     Q <- abs(2*(l1-l2))
     names(Q) <- "chisq"
     df <- abs(df1-df2); names(df) <- "df"
-    p <- 1-pchisq(Q,df=df)
+    p <- pchisq(Q,df=df,lower.tail=FALSE)
     values <- c(l1,l2); names(values) <- c("log likelihood (model 1)", "log likelihood (model 2)")
 
     res <- list(statistic = Q, parameter = df,
